%define pypi_name	pyopenssl
%define pkg_name	openssl

%bcond_without doc
%bcond_without check

Name:		python-%{pkg_name}
Version:	25.0.0
Release:	%mkrel 1
Summary:	Python interface to the OpenSSL library
License:	ASL 2.0
Group:		Development/Python
Url:		https://pypi.org/project/pyOpenSSL/
Source:		%{pypi_source}
Patch2:		0001-Limit-list-of-elliptic-curves-tested-to-those-in-Fed.patch
BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:	python3-devel
%if %{with check}
BuildRequires:  openssl
%endif
%if %{with doc}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
%endif

%description
pyOpenSSL is a high-level Python wrapper around a subset of OpenSSL library.

It includes:
* SSL.Connection objects, wrapping the methods of Python's portable sockets;
* callbacks written in Python;
* an extensive error-handling mechanism, mirroring OpenSSL's error codes;
* and much more.

%package -n python3-%{pkg_name}
Summary:	Python 3 wrapper module around the OpenSSL library
Group:		Development/Python
%{?python_provide:%python_provide python3-pyopenssl}
%{?python_provide:%python_provide python3-%{pkg_name}}
%{?python_provide:%python_provide python3-%{pypi_name}}
%{?python_provide:%python_provide python3-OpenSSL}

Obsoletes:      python3-OpenSSL < 23.0.0
Obsoletes:	python3-OpenSSL-doc < 23.0.0
Provides:       python3-OpenSSL = %{version}-%{release}

%description -n python3-%{pkg_name}
High-level wrapper around a subset of the OpenSSL library, includes among others
 * SSL.Connection objects, wrapping the methods of Python's portable
   sockets
 * Callbacks written in Python 3
 * Extensive error-handling mechanism, mirroring OpenSSL's error codes

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires %{?with_check:-x test}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%if %{with doc}
export PYTHONPATH=$(pwd)
sphinx-build doc html
sphinx-build -b man doc man
%endif

%install
%pyproject_install
%pyproject_save_files OpenSSL

%if %{with doc}
%__install -Dm 0644 man/pyopenssl.1 %{buildroot}%{_mandir}/man1/pyopenssl.1
%endif

%if %{with check}
%check
%pyproject_check_import
%pytest -k "not network" -k "not test_sign_verify_with_text" -k "not test_sign_verify"
%endif

%files -n python3-%{pkg_name} -f %{pyproject_files}
%if %{with doc}
%doc html
%{_mandir}/man1/pyopenssl.1*
%endif


%changelog
* Sat Mar 01 2025 daviddavid <daviddavid> 25.0.0-1.mga10
+ Revision: 2154160
- new version: 25.0.0
- rebuild for python 3.13

* Sat Jan 25 2025 daviddavid <daviddavid> 24.3.0-1.mga10
+ Revision: 2142317
- new version: 24.3.0

* Sat Jan 20 2024 wally <wally> 23.3.0-1.mga10
+ Revision: 2032961
- new version 23.3.0

* Sat Dec 09 2023 wally <wally> 23.2.0-2.mga10
+ Revision: 2016454
- rebuild for py3.12

* Thu Sep 07 2023 papoteur <papoteur> 23.2.0-1.mga10
+ Revision: 1985044
- new 23.2.0

* Sun Jan 15 2023 wally <wally> 23.0.0-1.mga9
+ Revision: 1933582
- rename src pkg as python-openssl
- new version 23.0.0
- enable docs

* Mon Nov 14 2022 guillomovitch <guillomovitch> 22.1.0-1.mga9
+ Revision: 1907297
- new version 22.1.0

* Wed Mar 30 2022 umeabot <umeabot> 22.0.0-2.mga9
+ Revision: 1834935
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 22.0.0-1.mga9
+ Revision: 1772470
- new version 22.0.0
- rebuild for python3.10

* Wed Dec 29 2021 joequant <joequant> 21.0.0-1.mga9
+ Revision: 1765317
- update to 21.0.0

* Sat Mar 20 2021 guillomovitch <guillomovitch> 20.0.1-1.mga9
+ Revision: 1705838
- new version 20.0.1
+ tv <tv>
- rebuild for python-3.9.2
+ neoclust <neoclust>
- Rebuild against python 3.9

* Sun Dec 13 2020 guillomovitch <guillomovitch> 20.0.0-1.mga8
+ Revision: 1656489
- new version 20.0.0

* Thu Mar 05 2020 kekepower <kekepower> 19.1.0-1.mga8
+ Revision: 1554152
- Update to version 19.1.0

* Sun Feb 16 2020 umeabot <umeabot> 19.0.0-2.mga8
+ Revision: 1530738
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 19.0.0-1.mga8
+ Revision: 1437379
- new version 19.0.0
- drop python2 support
- rebuild for python3.8

* Sat Jan 05 2019 wally <wally> 18.0.0-2.mga7
+ Revision: 1349672
- rebuild for python3.7 without docs

* Mon Nov 19 2018 kekepower <kekepower> 18.0.0-1.mga7
+ Revision: 1331641
- Update to version 18.0.0

* Thu Sep 20 2018 umeabot <umeabot> 17.5.0-4.mga7
+ Revision: 1288202
- Mageia 7 Mass Rebuild

* Sat Apr 07 2018 daviddavid <daviddavid> 17.5.0-3.mga7
+ Revision: 1215895
- python2-OpenSSL provides pyOpenSSL

* Thu Apr 05 2018 kekepower <kekepower> 17.5.0-2.mga7
+ Revision: 1215449
- Renamed python-OpenSSL to python2-OpenSSL

* Tue Mar 20 2018 sander85 <sander85> 17.5.0-1.mga7
+ Revision: 1210826
- New version: 17.5.0

* Mon Aug 07 2017 philippem <philippem> 17.2.0-1.mga7
+ Revision: 1138682
- upgrade to 17.2.0

* Sat Aug 05 2017 pterjan <pterjan> 16.0.0-2.mga7
+ Revision: 1135525
- Rebuild for python 3.6

* Mon Apr 11 2016 philippem <philippem> 16.0.0-1.mga6
+ Revision: 1000252
- update to 16.0.0

* Fri Feb 19 2016 umeabot <umeabot> 0.15.1-2.mga6
+ Revision: 970725
- Mageia 6 Mass Rebuild

* Fri Oct 09 2015 daviddavid <daviddavid> 0.15.1-1.mga6
+ Revision: 888063
- new version: 0.15.1
- rebuild for python 3.5

* Sun Mar 08 2015 philippem <philippem> 0.14-1.mga5
+ Revision: 818118
- update to 0.14

* Wed Oct 15 2014 umeabot <umeabot> 0.13.1-9.mga5
+ Revision: 749978
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.13.1-8.mga5
+ Revision: 729247
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.13.1-7.mga5
+ Revision: 687875
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 0.13.1-6.mga5
+ Revision: 629718
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 0.13.1-5.mga5
+ Revision: 628446
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.13.1-4.mga4
+ Revision: 543013
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.13.1-3.mga4
+ Revision: 498077
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 23 2013 philippem <philippem> 0.13.1-2.mga4
+ Revision: 484420
- Python 3 subpackage
- Split documentation off into noarch subpackage
- Change BuildRequires to texlive-dist

* Mon Sep 09 2013 oden <oden> 0.13.1-1.mga4
+ Revision: 476686
- 0.13.1 (fixes CVE-2013-4314)

* Sun Jan 13 2013 umeabot <umeabot> 0.13-2.mga3
+ Revision: 378442
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 blino <blino> 0.13-1.mga3
+ Revision: 337650
- 0.13 (needed for mitmproxy)

* Sun Jun 19 2011 kharec <kharec> 0.12-1.mga2
+ Revision: 109720
- new version 0.12

* Sat Apr 16 2011 ahmad <ahmad> 0.11-1.mga1
+ Revision: 86767
- update to 0.11
- change Url and Source urls to the new upstream web site
- drop explicit python runtime requires, already handled by the rpm build scripts
- move the cleaning of buildroot to %%install instead of %%prep

* Wed Mar 30 2011 ahmad <ahmad> 0.10-5.mga1
+ Revision: 78969
- replace tetex BR with texlive

* Thu Jan 20 2011 erwan <erwan> 0.10-4.mga1
+ Revision: 27425
- imported package python-OpenSSL

